==> koha-2.2.2b.tar.gz: koha-2.2.2b/intranet-cgi/value_builder/unimarc_field_116.pl <==
#!/usr/bin/perl

# $Id: unimarc_field_116.pl,v 1.1 2004/06/07 10:07:40 doxulting Exp $

# Copyright 2000-2002 Katipo Communications
#
# This file is part of Koha.
#
# Koha is free software; you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
#
# Koha is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# Koha; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
# Suite 330, Boston, MA  02111-1307 USA

use strict;
use C4::Auth;
use CGI;
use C4::Context;
use HTML::Template;
use C4::Search;
use C4::Output;

=head1

plugin_parameters : other parameters added when the plugin is called by the dopop function

=cut
sub plugin_parameters {
my ($dbh,$record,$tagslib,$i,$tabloop) = @_;
return "";
}

sub plugin_javascript {
my ($dbh,$record,$tagslib,$field_number,$tabloop) = @_;
my $function_name= "116".(int(rand(100000))+1);
my $res="
<script>
function Focus$function_name(subfield_managed) {
return 1;
}

function Blur$function_name(subfield_managed) {
	return 1;
}

function Clic$function_name(i) {
	defaultvalue=document.forms[0].field_value[i].value;
	newin=window.open(\"../plugin_launcher.pl?plugin_name=unimarc_field_116.pl&index=\"+i+\"&result=\"+defaultvalue,\"unimarc field 116\",'width=1200,height=600,toolbar=false,scrollbars=yes');

}
</script>
";

return ($function_name,$res);
}
sub plugin {
my ($input) = @_;
	my %env;

#	my $input = new CGI;
	my $index= $input->param('index');
	my $result= $input->param('result');

	my $dbh = C4::Context->dbh;
my ($template, $loggedinuser, $cookie)
    = get_template_and_user({template_name => "value_builder/unimarc_field_116.tmpl",
			     query => $input,
			     type => "intranet",
			     authnotrequired => 0,
			     flagsrequired => {parameters => 1},
			     debug => 1,
			     });
 	my $f1 = substr($result,0,1);
 	my $f2 = substr($result,1,1);
 	my $f3 = substr($result,2,1);
 	my $f4 = substr($result,3,1);

 	my $f5 = substr($result,4,2);
 	my $f6 = substr($result,6,2);
 	my $f7 = substr($result,8,2);

 	my $f8 = substr($result,10,2);
 	my $f9 = substr($result,12,2);
 	my $f10 = substr($result,14,2);

 	my $f11 = substr($result,16,2);

	$template->param(index => $index,
							"f1$f1" => $f1,
							"f2$f2" => $f2,
							"f3$f3" => $f3,
							"f4$f4" => $f4,
							"f5$f5" => $f5,
							"f6$f6" => $f6,
							"f7$f7" => $f7,
							"f8$f8" => $f8,
 							"f9$f9" => $f9,
 							"f10$f10" => $f10,
 							"f11$f11" => $f11
 );
	print $input->header(-cookie => $cookie),$template->output;
}

1;

==> koha-2.3.0.tar.gz: koha-2.3.0/intranet-cgi/value_builder/unimarc_field_116.pl <==
#!/usr/bin/perl

# $Id: unimarc_field_116.pl,v 1.1.2.2 2005/12/15 10:05:53 tipaul Exp $

# Copyright 2000-2002 Katipo Communications
#
# This file is part of Koha.
#
# Koha is free software; you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
#
# Koha is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# Koha; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
# Suite 330, Boston, MA  02111-1307 USA

use strict;
use C4::Auth;
use CGI;
use C4::Context;
use HTML::Template;
use C4::Search;
use C4::Output;

=head1

plugin_parameters : other parameters added when the plugin is called by the dopop function

=cut
sub plugin_parameters {
my ($dbh,$record,$tagslib,$i,$tabloop) = @_;
return "";
}

sub plugin_javascript {
my ($dbh,$record,$tagslib,$field_number,$tabloop) = @_;
my $function_name= "116".(int(rand(100000))+1);
my $res="
<script>
function Focus$function_name(subfield_managed) {
return 1;
}

function Blur$function_name(subfield_managed) {
	return 1;
}

function Clic$function_name(i) {
	defaultvalue=document.forms[0].field_value[i].value;
	newin=window.open(\"../plugin_launcher.pl?plugin_name=unimarc_field_116.pl&index=\"+i+\"&result=\"+defaultvalue,\"unimarc field 116\",'width=1200,height=600,toolbar=false,scrollbars=yes');

}
</script>
";

return ($function_name,$res);
}
sub plugin {
my ($input) = @_;
	my %env;

#	my $input = new CGI;
	my $index= $input->param('index');
	my $result= $input->param('result');

	my $dbh = C4::Context->dbh;
my ($template, $loggedinuser, $cookie)
    = get_template_and_user({template_name => "value_builder/unimarc_field_116.tmpl",
			     query => $input,
			     type => "intranet",
			     authnotrequired => 0,
			     flagsrequired => {editcatalogue => 1},
			     debug => 1,
			     });
 	my $f1 = substr($result,0,1);
 	my $f2 = substr($result,1,1);
 	my $f3 = substr($result,2,1);
 	my $f4 = substr($result,3,1);

 	my $f5 = substr($result,4,2);
 	my $f6 = substr($result,6,2);
 	my $f7 = substr($result,8,2);

 	my $f8 = substr($result,10,2);
 	my $f9 = substr($result,12,2);
 	my $f10 = substr($result,14,2);

 	my $f11 = substr($result,16,2);

	$template->param(index => $index,
							"f1$f1" => 1,
							"f2$f2" => 1,
							"f3$f3" => 1,
							"f4$f4" => 1,
							"f5$f5" => 1,
							"f6$f6" => 1,
							"f7$f7" => 1,
							"f8$f8" => 1,
 							"f9$f9" => 1,
 							"f10$f10" => 1,
 							"f11$f11" => 1
 );
	print $input->header(-cookie => $cookie),$template->output;
}

1;
